@@ -1,7 +1,7 @@
 package Dist::Zilla::Role::RequireFromBuild;
 
-our $DATE = '2017-01-08'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-09'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use Moose::Role;
@@ -15,7 +15,7 @@ sub require_from_build {
     }
 
     my @files = grep { $_->name eq "lib/$name" } @{ $self->zilla->files };
-    @files    = grep { $_->name eq $name }       $self->zilla->files
+    @files    = grep { $_->name eq $name }       @{ $self->zilla->files }
         unless @files;
     die "Can't find $name in lib/ or ./ in build files" unless @files;
 
@@ -41,7 +41,7 @@ Dist::Zilla::Role::RequireFromBuild - Role to require() from build files
 
 =head1 VERSION
 
-This document describes version 0.002 of Dist::Zilla::Role::RequireFromBuild (from Perl distribution Dist-Zilla-Role-RequireFromBuild), released on 2017-01-08.
+This document describes version 0.003 of Dist::Zilla::Role::RequireFromBuild (from Perl distribution Dist-Zilla-Role-RequireFromBuild), released on 2017-01-09.
 
 =head1 SYNOPSIS
 
@@ -67,7 +67,7 @@ $self->require_from_build("Foo::Bar") >> is a convenient shortcut for something
 like:
 
  my @files = grep { $_->name eq "lib/Foo/Bar.pm" } @{ $self->zilla->files };
- @files    = grep { $_->name eq "Foo/Bar.pm" }     $self->zilla->files unless @files;
+ @files    = grep { $_->name eq "Foo/Bar.pm" }     @{ $self->zilla->files } unless @files;
  die "Can't find Foo/Bar.pm in lib/ or ./ in build files" unless @files;
 
  eval $files[0]->encoded_content;
